function directionalNavigation(iD) {

  // Find the navigable items
  var id = '#' + iD;
  this.$svg = $(id).find('svg');
  
   this.$navigableItems = this.$svg.find('use');
//  var $g = this.$svg.find('g');
//  this.$navigableItems = $g.children();
  var array = this.$navigableItems.get();
  this.eightWayNav = new eightWayNav(array, this.$svg.get(0));

  this.$activeItem = null; // holds the jQuery object for the active item

  this.keys = {
            tab:      9,
            enter:    13,
            space:    32,
            pageup:   33,
            pagedown: 34,
            end:      35,
            home:     36,
            left:     37,
            up:       38,
            right:    39,
            down:     40,
            asterisk: 106,
            e:		  54,
            nw:		  55,
            n:		  56,
            ne:		  57,
            w:		  58,
            sw:		  49,
            se:		  51,
            s: 		  50
            
   };


 
  // bind event handlers
  this.bindHandlers();

} // end directionalNavigation() constructor

//
// Function bindHandlers() is a member function to bind event handlers to the navigable items
//
// return N/A
//
directionalNavigation.prototype.bindHandlers = function() {

  var thisObj = this;
  var $par = this.$svg.parent();
  
  // bind a click handler on each navigable item
  this.$navigableItems.click(function(e) {
    return thisObj.handleClick($(this), e);
  });

  // bind a keydown handler to the SVG object
  $par.keydown(function(e) {
    return thisObj.handleKeyDown(e);
  });

  // bind a keypress handler to the SVG object
  $par.keypress(function(e) {
    return thisObj.handleKeyPress(e);
  });

  // bind a focus handler to the SVG object
 

	  $par.focus(function(e) {
		if (this.$activeItem) {
			this.$activeItem.attr('tabindex', '0');
			// This is a bad thing to do, but it shows navigation in Firefox and
			// Chrome
			this.$activeItem.attr('class', 'activeElem');
			return thisObj.handleFocus(e);
		}
   
  });
	  
  $par.attr('tabindex', '0');

  // bind a blur handler to the SVG object
  this.$svg.blur(function(e) {
	  if (this.navigableItems) {
		  this.$navigableItems.removeAttr("class");
		  return thisObj.handleBlur(e);		  
	  }
  });

   // bind a document click handler
   $(document).click(function(e) {

         if (thisObj.$activeItem != null) {      
        	thisObj.$activeItem.attr('tabindex', '-1');
            thisObj.$activeItem = null;
         }
         thisObj.$svg.attr('tabindex', '0');

         return true;
   });

} // end bindHandlers()

//
//Function handleKeyDown() is a member function to process keydown events for navigation
//@param (e object) e is the associated event object
//@return (boolean) returns false if consuming event; true if not
//
directionalNavigation.prototype.handleKeyDown = function(e) {

	if ((e.altKey || e.ctrlKey) || (e.shiftKey && e.keyCode != this.keys.tab)) {
		// do nothing
		return true;
	}
	

	switch (e.keyCode) {
	case this.keys.left: 
	case this.keys.w:
	{
		// Move left
		var selected = this.eightWayNav.west();
		this.setActiveItem(selected);
		e.stopPropagation();
		return false;
	}
	case this.keys.right:
	case this.keys.w:
	{
		// Move right
		var selected = this.eightWayNav.east();
		this.setActiveItem(selected);
		e.stopPropagation();
		return false;
	}
	case this.keys.up: 
	case this.keys.n:
	{
		// Move up
		var selected = this.eightWayNav.north();
		this.setActiveItem(selected);
		e.stopPropagation();
		return false;
	}
	case this.keys.down: 
	case this.keys.s:
	{
		// Move down
		var selected = this.eightWayNav.south();
		this.setActiveItem(selected);
		e.stopPropagation();
		return false;
	}
	
	case this.keys.nw:
	case this.keys.home:
	{
		
		var selected = this.eightWayNav.northwest();
		this.setActiveItem(selected);
		e.stopPropagation();
		return false;
	}
	case this.keys.se:
	case this.keys.pagedown:
	{
		
		var selected = this.eightWayNav.southeast();
		this.setActiveItem(selected);
		e.stopPropagation();
		return false;
	}
	case this.keys.sw:
	case this.keys.end:
	{
		
		var selected = this.eightWayNav.southwest();
		this.setActiveItem(selected);
		e.stopPropagation();
		return false;
	}
	case this.keys.ne:
	case this.keys.pageup:
	{
		
		var selected = this.eightWayNav.northeast();
		this.setActiveItem(selected);
		e.stopPropagation();
		return false;
	}

	case this.keys.asterisk: {

		e.stopPropagation();
		return false;
	}
	}

	return true;

} // end handleKeyDown

directionalNavigation.prototype.setActiveItem = function(item) {
	  // update the active item and give it focus
	this.$activeItem = $(item);
	this.$navigableItems.attr('tabindex', '-1');
	// This is a bad thing to do, but it shows navigation in Firefox and Chrome
	this.$navigableItems.removeAttr("class");
	// removeClass is what we should be doing, but it does not affect the outerHTML 
	//  which needs to happen for SVG to pick up the CSS changes
//	this.$navigableItems.removeClass("activeElem");
	this.$svg.attr('tabindex', '0');
	if (this.$activeItem) {
		this.$activeItem.attr('tabindex', '0');
		// This is a bad thing to do, but it shows navigation in Firefox and Chrome
		this.$activeItem.attr('class', 'activeElem');
		// addClass is what we should be doing, but it does not affect the outerHTML
		// which needs to happen for SVG to pick up the CSS changes
//		this.$activeItem.addClass("activeElem");
		var elem = this.$activeItem.get(0);		
//		var bbox = elem.getBBox();
		this.$activeItem.focus();	
		console.log(elem);
//		var cx = bbox.x + bbox.width / 2.;
//		var cy = bbox.y + bbox.height / 2;
//		var center = cx + "," + cy;
//		console.log(center);
	} else {
		console.log("active item null");
	}
}
