// Constructor for an wrapper object to help navigation. 
// item is an svg object
// if rotate45 is true, the centerpoint will be rotated by 45 degrees
// This allows a navItem to be used for the cardinal direction navigation and another
// with rotate45 to be used for diagonal (off cardinal direction) navigation.
function navItem(item, rotate45, arrayX, arrayY, parent, svg) {
	this.item = item;
	this.calculateCenter(svg, rotate45);
	this.arrayX = arrayX;
	this.arrayY = arrayY;
	this.parent = parent;
	
	// Add this item to the arrays (will be sorted later)
	arrayX.push(this);
	arrayY.push(this);
}

navItem.prototype.getCenter = function() {
	var rect = this.item.getBBox();
	var cx = rect.x + rect.width / 2.;
	var cy = rect.y + rect.height / 2.;
	
	if (this.item.tagName == 'use' || this.item.tagName == 'USE') {
		cx += this.item.x.baseVal.value;
		cy += this.item.y.baseVal.value;
	}
	
	return {x: cx, y: cy};
}

// Calculate the center point 
navItem.prototype.calculateCenter = function(svg, rotate45) {
	// convert the center to the SVG element's coordinate system
	var m = svg.getTransformToElement(this.item);
	var c = this.getCenter();
	this.x = m.a * c.x + m.c * c.y + m.e;
	this.y = m.b * c.x + m.d * c.y + m.f;

	if (rotate45) {
		// Rotating coordinates 45 degrees 
		// cs45 is the sine and cosine of 45 degrees
		var cs45 = 0.7071067811865475244008443621048490392848359376884740;
		var rx = this.x * cs45;
		var ry = this.y * cs45;
		this.x = rx - ry;
		this.y = rx + ry;		
	}
}

navItem.prototype.greaterX = function() {
	// Allow movement within 45 degrees of the requested direction
	// x must be greater and abs(delta y) < delta x 	
	var index = this.arrayX.indexOf(this) + 1;  // Next index 
	
	while (index < this.arrayX.length) {
		var next = this.arrayX[index];  // candidate
		var dx = next.x - this.x;
		if (dx > 0) {					
			var dy = Math.abs(next.y - this.y);
			if (dx > dy) {				
				return next;  // has greater x, and abs(dy) < dx
			}
		}
		index++;
	}
	return this;
}

navItem.prototype.lesserX = function() {
	// Allow movement within 45 degrees of the requested direction
	// x must be lesser and abs(delta y) < delta x 	
	var index = this.arrayX.indexOf(this) - 1;	
	
	while (index > -1) {
		var next = this.arrayX[index];
		var dx = this.x - next.x;
		if (dx > 0) {
			var dy = Math.abs(this.y - next.y);
			if (dx > dy) {
				return next;
			}
		}
		index--;
	}
	return this;
}

navItem.prototype.greaterY = function() {
	// Allow movement within 45 degrees of the requested direction
	// y must be greater and abs(delta x) < delta Y 	
	var index = this.arrayY.indexOf(this) + 1;  // Next index 
	
	while (index < this.arrayY.length) {
		var next = this.arrayY[index];  // candidate
		var dy = next.y - this.y;
		if (dy > 0) {					
			var dx = Math.abs(next.x - this.x);
			if (dy > dx) {				
				return next;  // has greater y, and abs(dx) < dy
			}
		}
		index++;
	}
	return this;
}

navItem.prototype.lesserY = function() {
	// Allow movement within 45 degrees of the requested direction
	// y must be lesser and abs(delta x) < delta y 	
	var index = this.arrayY.indexOf(this) - 1;	
	
	while (index > -1) {
		var next = this.arrayY[index];
		var dy = this.y - next.y;
		if (dy > 0) {
			var dx = Math.abs(this.x - next.x);
			if (dy > dx) {
				return next;
			}
		}
		index--;
	}
	return this;
}

navItem.prototype.getParent = function() {
	return this.parent;
}


